Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(297)

Unified Diff: pkg/compiler/lib/src/js_backend/backend_serialization.dart

Issue 2603263002: Prefix resolution_types with Resolution. (Closed)
Patch Set: Rebased Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/js_backend/backend_serialization.dart
diff --git a/pkg/compiler/lib/src/js_backend/backend_serialization.dart b/pkg/compiler/lib/src/js_backend/backend_serialization.dart
index 3b9818efa1b1fecdd753f36387ebd987c948388d..834daaea3b87b0111bfae81654913cd8dbac5485 100644
--- a/pkg/compiler/lib/src/js_backend/backend_serialization.dart
+++ b/pkg/compiler/lib/src/js_backend/backend_serialization.dart
@@ -156,7 +156,7 @@ class NativeBehaviorSerialization {
static const int SPECIAL_TYPE = 2;
static int getTypeKind(var type) {
- if (type is DartType) {
+ if (type is ResolutionDartType) {
// TODO(johnniwinther): Remove this when annotation are no longer resolved
// to this-types.
if (type is GenericType &&
@@ -169,8 +169,8 @@ class NativeBehaviorSerialization {
return SPECIAL_TYPE;
}
- /// Returns a list of the non-this-type [DartType]s in [types].
- static List<DartType> filterDartTypes(List types) {
+ /// Returns a list of the non-this-type [ResolutionDartType]s in [types].
+ static List<ResolutionDartType> filterDartTypes(List types) {
return types.where((type) => getTypeKind(type) == NORMAL_TYPE).toList();
}
« no previous file with comments | « pkg/compiler/lib/src/js_backend/backend_impact.dart ('k') | pkg/compiler/lib/src/js_backend/checked_mode_helpers.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698